@@ -1,4 +1,4 @@
-# Copyright (c) 2019 - 2024, Adrian Dusa
+# Copyright (c) 2019 - 2025, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -179,9 +179,14 @@
 `print.admisc_fobject` <- function(x, startend = TRUE, ...) {
     class(x) <- setdiff(class(x), "admisc_fobject")
     if (is.list(x)) {
-        nms <- apply(attr(x, "split", exact = TRUE), 1, function(x) {
-            paste(x, collapse = ", ")
-        })
+        split <- attr(x, "split")
+        if (is.matrix(split)) {
+            nms <- apply(attr(x, "split", exact = TRUE), 1, function(x) {
+                paste(x, collapse = ", ")
+            })
+        } else {
+            nms <- split
+        }
         cat(ifelse(startend, "\n", ""))
         for (i in seq(length(x))) {
             cat(nms[i], "\n")
